@@ -52,7 +52,7 @@ __all__ = ('xmod',)
 import functools
 import sys
 
-__version__ = '1.3.0'
+__version__ = '1.3.1'
 
 OMIT = {
     '__class__',
@@ -130,8 +130,8 @@ def xmod(
         return wrapped
 
     def mutator(f):
-        def fail(*_):
-            raise TypeError('Class is immutable')
+        def fail(*args, **kwargs):
+            raise TypeError(f'Class is immutable {args} {kwargs}')
 
         return method(f) if mutable else fail
 
@@ -141,8 +141,12 @@ def xmod(
             mutator(lambda v: setattr(extension, k, v)),
             mutator(lambda: delattr(extension, k)),
         )
+    if name is None:
+        if isinstance(extension, functools.partial):
+            name = extension.func.__module__
+        else:
+            name = extension.__module__
 
-    name = extension.__module__ if name is None else name
     module = sys.modules[name]
 
     def _getattr(k):
@@ -195,7 +199,7 @@ def xmod(
             is_magic = a.startswith('__') and callable(value)
             if is_magic:
                 members[a] = method(value)
-            else:
+            elif False:  # TODO: enable or delete this
                 members[a] = prop(a)
 
     def directory(self):
